==> stac_fastapi_opensearch-3.1.0.tar.gz: stac_fastapi_opensearch-3.1.0/setup.py <==
"""stac_fastapi: opensearch module."""

from setuptools import find_namespace_packages, setup

with open("README.md") as f:
    desc = f.read()

install_requires = [
    "stac-fastapi.core==3.1.0",
    "opensearch-py==2.4.2",
    "opensearch-py[async]==2.4.2",
    "uvicorn",
    "starlette",
]

extra_reqs = {
    "dev": [
        "pytest",
        "pytest-cov",
        "pytest-asyncio",
        "pre-commit",
        "requests",
        "ciso8601",
        "httpx",
    ],
    "docs": ["mkdocs", "mkdocs-material", "pdocs"],
    "server": ["uvicorn[standard]==0.19.0"],
}

setup(
    name="stac-fastapi.opensearch",
    description="Opensearch stac-fastapi backend.",
    long_description=desc,
    long_description_content_type="text/markdown",
    python_requires=">=3.8",
    classifiers=[
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: MIT License",
    ],
    url="https://github.com/stac-utils/stac-fastapi-elasticsearch-opensearch",
    license="MIT",
    packages=find_namespace_packages(),
    zip_safe=False,
    install_requires=install_requires,
    extras_require=extra_reqs,
    entry_points={
        "console_scripts": ["stac-fastapi-opensearch=stac_fastapi.opensearch.app:run"]
    },
)

==> stac_fastapi_opensearch-4.0.0.tar.gz: stac_fastapi_opensearch-4.0.0/setup.py <==
"""stac_fastapi: opensearch module."""

from setuptools import find_namespace_packages, setup

with open("README.md") as f:
    desc = f.read()

install_requires = [
    "stac-fastapi-core==4.0.0",
    "opensearch-py~=2.8.0",
    "opensearch-py[async]~=2.8.0",
    "uvicorn~=0.23.0",
    "starlette>=0.35.0,<0.36.0",
]

extra_reqs = {
    "dev": [
        "pytest~=7.0.0",
        "pytest-cov~=4.0.0",
        "pytest-asyncio~=0.21.0",
        "pre-commit~=3.0.0",
        "requests>=2.32.0,<3.0.0",
        "ciso8601~=2.3.0",
        "httpx>=0.24.0,<0.28.0",
    ],
    "docs": ["mkdocs~=1.4.0", "mkdocs-material~=9.0.0", "pdocs~=1.2.0"],
    "server": ["uvicorn[standard]~=0.23.0"],
}

setup(
    name="stac_fastapi_opensearch",
    description="Opensearch stac-fastapi backend.",
    long_description=desc,
    long_description_content_type="text/markdown",
    python_requires=">=3.9",
    classifiers=[
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "License :: OSI Approved :: MIT License",
    ],
    url="https://github.com/stac-utils/stac-fastapi-elasticsearch-opensearch",
    license="MIT",
    packages=find_namespace_packages(),
    zip_safe=False,
    install_requires=install_requires,
    extras_require=extra_reqs,
    entry_points={
        "console_scripts": ["stac-fastapi-opensearch=stac_fastapi.opensearch.app:run"]
    },
)
